"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class APIService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___APIServiceSpec: ...
    @property
    def status(self) -> global___APIServiceStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___APIServiceSpec | None = ...,
        status: global___APIServiceStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___APIService = APIService

@typing_extensions.final
class APIServiceCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___APIServiceCondition = APIServiceCondition

@typing_extensions.final
class APIServiceList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___APIService]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___APIService] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___APIServiceList = APIServiceList

@typing_extensions.final
class APIServiceSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CA_BUNDLE_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    GROUP_PRIORITY_MINIMUM_FIELD_NUMBER: builtins.int
    INSECURE_SKIP_TLS_VERIFY_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    VERSION_PRIORITY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ca_bundle: builtins.str
    group: builtins.str
    group_priority_minimum: builtins.int
    insecure_skip_tls_verify: builtins.bool
    @property
    def service(self) -> global___ServiceReference: ...
    version: builtins.str
    version_priority: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ca_bundle: builtins.str = ...,
        group: builtins.str = ...,
        group_priority_minimum: builtins.int = ...,
        insecure_skip_tls_verify: builtins.bool = ...,
        service: global___ServiceReference | None = ...,
        version: builtins.str = ...,
        version_priority: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ca_bundle", b"ca_bundle", "group", b"group", "group_priority_minimum", b"group_priority_minimum", "insecure_skip_tls_verify", b"insecure_skip_tls_verify", "resource_info", b"resource_info", "service", b"service", "version", b"version", "version_priority", b"version_priority"]) -> None: ...

global___APIServiceSpec = APIServiceSpec

@typing_extensions.final
class APIServiceStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___APIServiceCondition]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        conditions: collections.abc.Iterable[global___APIServiceCondition] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conditions", b"conditions", "resource_info", b"resource_info"]) -> None: ...

global___APIServiceStatus = APIServiceStatus

@typing_extensions.final
class ServiceReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    namespace: builtins.str
    port: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        port: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "namespace", b"namespace", "port", b"port", "resource_info", b"resource_info"]) -> None: ...

global___ServiceReference = ServiceReference



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.apps.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg import runtime_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_runtime__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.util import intstr_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_util_dot_intstr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.kubernetes/kubernetes_io.k8s.api.apps.v1.proto\x12\x1boak9.tython.k8s.api.apps.v1\x1a\x13shared/shared.proto\x1a;kubernetes/kubernetes_io.k8s.apimachinery.pkg.runtime.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x1a?kubernetes/kubernetes_io.k8s.apimachinery.pkg.util.intstr.proto\"\x95\x02\n\x12\x43ontrollerRevision\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.oak9.tython.k8s.apimachinery.pkg.runtime.RawExtension\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12K\n\x08metadata\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x10\n\x08revision\x18\x05 \x01(\x05\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xff\x01\n\x16\x43ontrollerRevisionList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12>\n\x05items\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.apps.v1.ControllerRevision\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xac\x02\n\tDaemonSet\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x38\n\x04spec\x18\x04 \x01(\x0b\x32*.oak9.tython.k8s.api.apps.v1.DaemonSetSpec\x12<\n\x06status\x18\x05 \x01(\x0b\x32,.oak9.tython.k8s.api.apps.v1.DaemonSetStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdf\x01\n\x12\x44\x61\x65monSetCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n\rDaemonSetList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.oak9.tython.k8s.api.apps.v1.DaemonSet\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe2\x02\n\rDaemonSetSpec\x12\x19\n\x11min_ready_seconds\x18\x01 \x01(\x05\x12\x1e\n\x16revision_history_limit\x18\x02 \x01(\x05\x12N\n\x08selector\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12>\n\x08template\x18\x04 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12M\n\x0fupdate_strategy\x18\x05 \x01(\x0b\x32\x34.oak9.tython.k8s.api.apps.v1.DaemonSetUpdateStrategy\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x94\x03\n\x0f\x44\x61\x65monSetStatus\x12\x17\n\x0f\x63ollision_count\x18\x01 \x01(\x05\x12\x43\n\nconditions\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.apps.v1.DaemonSetCondition\x12 \n\x18\x63urrent_number_scheduled\x18\x03 \x01(\x05\x12 \n\x18\x64\x65sired_number_scheduled\x18\x04 \x01(\x05\x12\x18\n\x10number_available\x18\x05 \x01(\x05\x12\x1b\n\x13number_misscheduled\x18\x06 \x01(\x05\x12\x14\n\x0cnumber_ready\x18\x07 \x01(\x05\x12\x1a\n\x12number_unavailable\x18\x08 \x01(\x05\x12\x1b\n\x13observed_generation\x18\t \x01(\x05\x12 \n\x18updated_number_scheduled\x18\n \x01(\x05\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xad\x01\n\x17\x44\x61\x65monSetUpdateStrategy\x12K\n\x0erolling_update\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.api.apps.v1.RollingUpdateDaemonSet\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaf\x02\n\nDeployment\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x39\n\x04spec\x18\x04 \x01(\x0b\x32+.oak9.tython.k8s.api.apps.v1.DeploymentSpec\x12=\n\x06status\x18\x05 \x01(\x0b\x32-.oak9.tython.k8s.api.apps.v1.DeploymentStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaf\x02\n\x13\x44\x65ploymentCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12M\n\x10last_update_time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xef\x01\n\x0e\x44\x65ploymentList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.oak9.tython.k8s.api.apps.v1.Deployment\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9c\x03\n\x0e\x44\x65ploymentSpec\x12\x19\n\x11min_ready_seconds\x18\x01 \x01(\x05\x12\x0e\n\x06paused\x18\x02 \x01(\x08\x12!\n\x19progress_deadline_seconds\x18\x03 \x01(\x05\x12\x10\n\x08replicas\x18\x04 \x01(\x05\x12\x1e\n\x16revision_history_limit\x18\x05 \x01(\x05\x12N\n\x08selector\x18\x06 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x41\n\x08strategy\x18\x07 \x01(\x0b\x32/.oak9.tython.k8s.api.apps.v1.DeploymentStrategy\x12>\n\x08template\x18\x08 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc5\x02\n\x10\x44\x65ploymentStatus\x12\x1a\n\x12\x61vailable_replicas\x18\x01 \x01(\x05\x12\x17\n\x0f\x63ollision_count\x18\x02 \x01(\x05\x12\x44\n\nconditions\x18\x03 \x03(\x0b\x32\x30.oak9.tython.k8s.api.apps.v1.DeploymentCondition\x12\x1b\n\x13observed_generation\x18\x04 \x01(\x05\x12\x16\n\x0eready_replicas\x18\x05 \x01(\x05\x12\x10\n\x08replicas\x18\x06 \x01(\x05\x12\x1c\n\x14unavailable_replicas\x18\x07 \x01(\x05\x12\x18\n\x10updated_replicas\x18\x08 \x01(\x05\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa9\x01\n\x12\x44\x65ploymentStrategy\x12L\n\x0erolling_update\x18\x01 \x01(\x0b\x32\x34.oak9.tython.k8s.api.apps.v1.RollingUpdateDeployment\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaf\x02\n\nReplicaSet\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x39\n\x04spec\x18\x04 \x01(\x0b\x32+.oak9.tython.k8s.api.apps.v1.ReplicaSetSpec\x12=\n\x06status\x18\x05 \x01(\x0b\x32-.oak9.tython.k8s.api.apps.v1.ReplicaSetStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe0\x01\n\x13ReplicaSetCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xef\x01\n\x0eReplicaSetList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.oak9.tython.k8s.api.apps.v1.ReplicaSet\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x86\x02\n\x0eReplicaSetSpec\x12\x19\n\x11min_ready_seconds\x18\x01 \x01(\x05\x12\x10\n\x08replicas\x18\x02 \x01(\x05\x12N\n\x08selector\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12>\n\x08template\x18\x04 \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x94\x02\n\x10ReplicaSetStatus\x12\x1a\n\x12\x61vailable_replicas\x18\x01 \x01(\x05\x12\x44\n\nconditions\x18\x02 \x03(\x0b\x32\x30.oak9.tython.k8s.api.apps.v1.ReplicaSetCondition\x12\x1e\n\x16\x66ully_labeled_replicas\x18\x03 \x01(\x05\x12\x1b\n\x13observed_generation\x18\x04 \x01(\x05\x12\x16\n\x0eready_replicas\x18\x05 \x01(\x05\x12\x10\n\x08replicas\x18\x06 \x01(\x05\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf3\x01\n\x16RollingUpdateDaemonSet\x12L\n\tmax_surge\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12R\n\x0fmax_unavailable\x18\x02 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf4\x01\n\x17RollingUpdateDeployment\x12L\n\tmax_surge\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12R\n\x0fmax_unavailable\x18\x02 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc2\x01\n RollingUpdateStatefulSetStrategy\x12R\n\x0fmax_unavailable\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12\x11\n\tpartition\x18\x02 \x01(\x05\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb2\x02\n\x0bStatefulSet\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12:\n\x04spec\x18\x04 \x01(\x0b\x32,.oak9.tython.k8s.api.apps.v1.StatefulSetSpec\x12>\n\x06status\x18\x05 \x01(\x0b\x32..oak9.tython.k8s.api.apps.v1.StatefulSetStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe1\x01\n\x14StatefulSetCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf1\x01\n\x0fStatefulSetList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x37\n\x05items\x18\x02 \x03(\x0b\x32(.oak9.tython.k8s.api.apps.v1.StatefulSet\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n\x13StatefulSetOrdinals\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x95\x01\n/StatefulSetPersistentVolumeClaimRetentionPolicy\x12\x14\n\x0cwhen_deleted\x18\x01 \x01(\t\x12\x13\n\x0bwhen_scaled\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc5\x05\n\x0fStatefulSetSpec\x12\x19\n\x11min_ready_seconds\x18\x01 \x01(\x05\x12\x42\n\x08ordinals\x18\x02 \x01(\x0b\x32\x30.oak9.tython.k8s.api.apps.v1.StatefulSetOrdinals\x12~\n(persistent_volume_claim_retention_policy\x18\x03 \x01(\x0b\x32L.oak9.tython.k8s.api.apps.v1.StatefulSetPersistentVolumeClaimRetentionPolicy\x12\x1d\n\x15pod_management_policy\x18\x04 \x01(\t\x12\x10\n\x08replicas\x18\x05 \x01(\x05\x12\x1e\n\x16revision_history_limit\x18\x06 \x01(\x05\x12N\n\x08selector\x18\x07 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x14\n\x0cservice_name\x18\x08 \x01(\t\x12>\n\x08template\x18\t \x01(\x0b\x32,.oak9.tython.k8s.api.core.v1.PodTemplateSpec\x12O\n\x0fupdate_strategy\x18\n \x01(\x0b\x32\x36.oak9.tython.k8s.api.apps.v1.StatefulSetUpdateStrategy\x12R\n\x16volume_claim_templates\x18\x0b \x03(\x0b\x32\x32.oak9.tython.k8s.api.core.v1.PersistentVolumeClaim\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf6\x02\n\x11StatefulSetStatus\x12\x1a\n\x12\x61vailable_replicas\x18\x01 \x01(\x05\x12\x17\n\x0f\x63ollision_count\x18\x02 \x01(\x05\x12\x45\n\nconditions\x18\x03 \x03(\x0b\x32\x31.oak9.tython.k8s.api.apps.v1.StatefulSetCondition\x12\x18\n\x10\x63urrent_replicas\x18\x04 \x01(\x05\x12\x18\n\x10\x63urrent_revision\x18\x05 \x01(\t\x12\x1b\n\x13observed_generation\x18\x06 \x01(\x05\x12\x16\n\x0eready_replicas\x18\x07 \x01(\x05\x12\x10\n\x08replicas\x18\x08 \x01(\x05\x12\x17\n\x0fupdate_revision\x18\t \x01(\t\x12\x18\n\x10updated_replicas\x18\n \x01(\x05\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb9\x01\n\x19StatefulSetUpdateStrategy\x12U\n\x0erolling_update\x18\x01 \x01(\x0b\x32=.oak9.tython.k8s.api.apps.v1.RollingUpdateStatefulSetStrategy\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.apps.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONTROLLERREVISION._serialized_start=341
  _CONTROLLERREVISION._serialized_end=618
  _CONTROLLERREVISIONLIST._serialized_start=621
  _CONTROLLERREVISIONLIST._serialized_end=876
  _DAEMONSET._serialized_start=879
  _DAEMONSET._serialized_end=1179
  _DAEMONSETCONDITION._serialized_start=1182
  _DAEMONSETCONDITION._serialized_end=1405
  _DAEMONSETLIST._serialized_start=1408
  _DAEMONSETLIST._serialized_end=1645
  _DAEMONSETSPEC._serialized_start=1648
  _DAEMONSETSPEC._serialized_end=2002
  _DAEMONSETSTATUS._serialized_start=2005
  _DAEMONSETSTATUS._serialized_end=2409
  _DAEMONSETUPDATESTRATEGY._serialized_start=2412
  _DAEMONSETUPDATESTRATEGY._serialized_end=2585
  _DEPLOYMENT._serialized_start=2588
  _DEPLOYMENT._serialized_end=2891
  _DEPLOYMENTCONDITION._serialized_start=2894
  _DEPLOYMENTCONDITION._serialized_end=3197
  _DEPLOYMENTLIST._serialized_start=3200
  _DEPLOYMENTLIST._serialized_end=3439
  _DEPLOYMENTSPEC._serialized_start=3442
  _DEPLOYMENTSPEC._serialized_end=3854
  _DEPLOYMENTSTATUS._serialized_start=3857
  _DEPLOYMENTSTATUS._serialized_end=4182
  _DEPLOYMENTSTRATEGY._serialized_start=4185
  _DEPLOYMENTSTRATEGY._serialized_end=4354
  _REPLICASET._serialized_start=4357
  _REPLICASET._serialized_end=4660
  _REPLICASETCONDITION._serialized_start=4663
  _REPLICASETCONDITION._serialized_end=4887
  _REPLICASETLIST._serialized_start=4890
  _REPLICASETLIST._serialized_end=5129
  _REPLICASETSPEC._serialized_start=5132
  _REPLICASETSPEC._serialized_end=5394
  _REPLICASETSTATUS._serialized_start=5397
  _REPLICASETSTATUS._serialized_end=5673
  _ROLLINGUPDATEDAEMONSET._serialized_start=5676
  _ROLLINGUPDATEDAEMONSET._serialized_end=5919
  _ROLLINGUPDATEDEPLOYMENT._serialized_start=5922
  _ROLLINGUPDATEDEPLOYMENT._serialized_end=6166
  _ROLLINGUPDATESTATEFULSETSTRATEGY._serialized_start=6169
  _ROLLINGUPDATESTATEFULSETSTRATEGY._serialized_end=6363
  _STATEFULSET._serialized_start=6366
  _STATEFULSET._serialized_end=6672
  _STATEFULSETCONDITION._serialized_start=6675
  _STATEFULSETCONDITION._serialized_end=6900
  _STATEFULSETLIST._serialized_start=6903
  _STATEFULSETLIST._serialized_end=7144
  _STATEFULSETORDINALS._serialized_start=7146
  _STATEFULSETORDINALS._serialized_end=7239
  _STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY._serialized_start=7242
  _STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY._serialized_end=7391
  _STATEFULSETSPEC._serialized_start=7394
  _STATEFULSETSPEC._serialized_end=8103
  _STATEFULSETSTATUS._serialized_start=8106
  _STATEFULSETSTATUS._serialized_end=8480
  _STATEFULSETUPDATESTRATEGY._serialized_start=8483
  _STATEFULSETUPDATESTRATEGY._serialized_end=8668
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_cloudarmor_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_compute_security_pb2 as gcp_dot_gcp__compute__security__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&gcp/gcp_google_cloudarmor_bundle.proto\x12(oak9.tython.gcp.google_cloudarmor_bundle\x1a\x13shared/shared.proto\x1a\x1egcp/gcp_compute_security.proto\"l\n\x10GoogleCloudarmor\x12X\n\x17\x63ompute_security_policy\x18\x01 \x01(\x0b\x32\x37.oak9.tython.gcp.compute_security.ComputeSecurityPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_cloudarmor_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECLOUDARMOR._serialized_start=137
  _GOOGLECLOUDARMOR._serialized_end=245
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ServerEngineAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ServerEngineAttribute = ServerEngineAttribute

@typing_extensions.final
class Server(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_PAIR_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_ARN_FIELD_NUMBER: builtins.int
    DISABLE_AUTOMATED_BACKUP_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    ENGINE_MODEL_FIELD_NUMBER: builtins.int
    PREFERRED_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    ASSOCIATE_PUBLIC_IP_ADDRESS_FIELD_NUMBER: builtins.int
    INSTANCE_PROFILE_ARN_FIELD_NUMBER: builtins.int
    CUSTOM_CERTIFICATE_FIELD_NUMBER: builtins.int
    PREFERRED_BACKUP_WINDOW_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    CUSTOM_DOMAIN_FIELD_NUMBER: builtins.int
    CUSTOM_PRIVATE_KEY_FIELD_NUMBER: builtins.int
    SERVER_NAME_FIELD_NUMBER: builtins.int
    ENGINE_ATTRIBUTES_FIELD_NUMBER: builtins.int
    BACKUP_RETENTION_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ENGINE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key_pair: builtins.str
    engine_version: builtins.str
    service_role_arn: builtins.str
    disable_automated_backup: builtins.bool
    backup_id: builtins.str
    engine_model: builtins.str
    preferred_maintenance_window: builtins.str
    associate_public_ip_address: builtins.bool
    instance_profile_arn: builtins.str
    custom_certificate: builtins.str
    preferred_backup_window: builtins.str
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    custom_domain: builtins.str
    custom_private_key: builtins.str
    server_name: builtins.str
    @property
    def engine_attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServerEngineAttribute]: ...
    backup_retention_count: builtins.int
    instance_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    engine: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key_pair: builtins.str = ...,
        engine_version: builtins.str = ...,
        service_role_arn: builtins.str = ...,
        disable_automated_backup: builtins.bool = ...,
        backup_id: builtins.str = ...,
        engine_model: builtins.str = ...,
        preferred_maintenance_window: builtins.str = ...,
        associate_public_ip_address: builtins.bool = ...,
        instance_profile_arn: builtins.str = ...,
        custom_certificate: builtins.str = ...,
        preferred_backup_window: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        custom_domain: builtins.str = ...,
        custom_private_key: builtins.str = ...,
        server_name: builtins.str = ...,
        engine_attributes: collections.abc.Iterable[global___ServerEngineAttribute] | None = ...,
        backup_retention_count: builtins.int = ...,
        instance_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        engine: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["associate_public_ip_address", b"associate_public_ip_address", "backup_id", b"backup_id", "backup_retention_count", b"backup_retention_count", "custom_certificate", b"custom_certificate", "custom_domain", b"custom_domain", "custom_private_key", b"custom_private_key", "disable_automated_backup", b"disable_automated_backup", "engine", b"engine", "engine_attributes", b"engine_attributes", "engine_model", b"engine_model", "engine_version", b"engine_version", "instance_profile_arn", b"instance_profile_arn", "instance_type", b"instance_type", "key_pair", b"key_pair", "preferred_backup_window", b"preferred_backup_window", "preferred_maintenance_window", b"preferred_maintenance_window", "resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "server_name", b"server_name", "service_role_arn", b"service_role_arn", "subnet_ids", b"subnet_ids", "tags", b"tags"]) -> None: ...

global___Server = Server

@typing_extensions.final
class OpsWorksCM(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_FIELD_NUMBER: builtins.int
    @property
    def server(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Server]: ...
    def __init__(
        self,
        *,
        server: collections.abc.Iterable[global___Server] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["server", b"server"]) -> None: ...

global___OpsWorksCM = OpsWorksCM



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_apigee.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gcp/gcp_apigee.proto\x12\x16oak9.tython.gcp.apigee\x1a\x13shared/shared.proto\"C\n!ApigeeEndpointAttachmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xa6\x02\n\x18\x41pigeeEndpointAttachment\x12\x1e\n\x16\x65ndpoint_attachment_id\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06org_id\x18\x06 \x01(\t\x12\x1a\n\x12service_attachment\x18\x07 \x01(\t\x12K\n\x08timeouts\x18\x08 \x01(\x0b\x32\x39.oak9.tython.gcp.apigee.ApigeeEndpointAttachmentXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"I\n\x17\x41pigeeEnvgroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc9\x01\n\x0e\x41pigeeEnvgroup\x12\x11\n\thostnames\x18\x01 \x03(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x41\n\x08timeouts\x18\x05 \x01(\x0b\x32/.oak9.tython.gcp.apigee.ApigeeEnvgroupXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"C\n!ApigeeEnvgroupAttachmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xe4\x01\n\x18\x41pigeeEnvgroupAttachment\x12\x13\n\x0b\x65nvgroup_id\x18\x01 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12K\n\x08timeouts\x18\x05 \x01(\x0b\x32\x39.oak9.tython.gcp.apigee.ApigeeEnvgroupAttachmentXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n\x1a\x41pigeeEnvironmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x98\x02\n\x11\x41pigeeEnvironment\x12\x16\n\x0e\x61pi_proxy_type\x18\x01 \x01(\t\x12\x17\n\x0f\x64\x65ployment_type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06org_id\x18\x07 \x01(\t\x12\x44\n\x08timeouts\x18\x08 \x01(\x0b\x32\x32.oak9.tython.gcp.apigee.ApigeeEnvironmentXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n%ApigeeEnvironmentIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x81\x02\n\x1b\x41pigeeEnvironmentIamBinding\x12\x0e\n\x06\x65nv_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0e\n\x06org_id\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12P\n\tcondition\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.apigee.ApigeeEnvironmentIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n$ApigeeEnvironmentIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xfe\x01\n\x1a\x41pigeeEnvironmentIamMember\x12\x0e\n\x06\x65nv_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0e\n\x06org_id\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12O\n\tcondition\x18\x07 \x01(\x0b\x32<.oak9.tython.gcp.apigee.ApigeeEnvironmentIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa4\x01\n\x1a\x41pigeeEnvironmentIamPolicy\x12\x0e\n\x06\x65nv_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06org_id\x18\x04 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"9\n\x17\x41pigeeInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x99\x03\n\x0e\x41pigeeInstance\x12\x1c\n\x14\x63onsumer_accept_list\x18\x01 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12 \n\x18\x64isk_encryption_key_name\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x0c\n\x04host\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x10\n\x08ip_range\x18\x07 \x01(\t\x12\x10\n\x08location\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0e\n\x06org_id\x18\n \x01(\t\x12\x1a\n\x12peering_cidr_range\x18\x0b \x01(\t\x12\x0c\n\x04port\x18\x0c \x01(\t\x12\x1a\n\x12service_attachment\x18\r \x01(\t\x12\x41\n\x08timeouts\x18\x0e \x01(\x0b\x32/.oak9.tython.gcp.apigee.ApigeeInstanceXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"C\n!ApigeeInstanceAttachmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xe4\x01\n\x18\x41pigeeInstanceAttachment\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12K\n\x08timeouts\x18\x05 \x01(\x0b\x32\x39.oak9.tython.gcp.apigee.ApigeeInstanceAttachmentXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"M\n\x1b\x41pigeeOrganizationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb0\x03\n\x12\x41pigeeOrganization\x12\x18\n\x10\x61nalytics_region\x18\x01 \x01(\t\x12\x1a\n\x12\x61uthorized_network\x18\x02 \x01(\t\x12\x14\n\x0c\x62illing_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63\x61_certificate\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12,\n$runtime_database_encryption_key_name\x18\n \x01(\t\x12\x14\n\x0cruntime_type\x18\x0b \x01(\t\x12\x19\n\x11subscription_type\x18\x0c \x01(\t\x12\x45\n\x08timeouts\x18\r \x01(\x0b\x32\x33.oak9.tython.gcp.apigee.ApigeeOrganizationXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_apigee_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APIGEEENDPOINTATTACHMENTXTIMEOUTS._serialized_start=69
  _APIGEEENDPOINTATTACHMENTXTIMEOUTS._serialized_end=136
  _APIGEEENDPOINTATTACHMENT._serialized_start=139
  _APIGEEENDPOINTATTACHMENT._serialized_end=433
  _APIGEEENVGROUPXTIMEOUTS._serialized_start=435
  _APIGEEENVGROUPXTIMEOUTS._serialized_end=508
  _APIGEEENVGROUP._serialized_start=511
  _APIGEEENVGROUP._serialized_end=712
  _APIGEEENVGROUPATTACHMENTXTIMEOUTS._serialized_start=714
  _APIGEEENVGROUPATTACHMENTXTIMEOUTS._serialized_end=781
  _APIGEEENVGROUPATTACHMENT._serialized_start=784
  _APIGEEENVGROUPATTACHMENT._serialized_end=1012
  _APIGEEENVIRONMENTXTIMEOUTS._serialized_start=1014
  _APIGEEENVIRONMENTXTIMEOUTS._serialized_end=1090
  _APIGEEENVIRONMENT._serialized_start=1093
  _APIGEEENVIRONMENT._serialized_end=1373
  _APIGEEENVIRONMENTIAMBINDINGXCONDITION._serialized_start=1375
  _APIGEEENVIRONMENTIAMBINDINGXCONDITION._serialized_end=1470
  _APIGEEENVIRONMENTIAMBINDING._serialized_start=1473
  _APIGEEENVIRONMENTIAMBINDING._serialized_end=1730
  _APIGEEENVIRONMENTIAMMEMBERXCONDITION._serialized_start=1732
  _APIGEEENVIRONMENTIAMMEMBERXCONDITION._serialized_end=1826
  _APIGEEENVIRONMENTIAMMEMBER._serialized_start=1829
  _APIGEEENVIRONMENTIAMMEMBER._serialized_end=2083
  _APIGEEENVIRONMENTIAMPOLICY._serialized_start=2086
  _APIGEEENVIRONMENTIAMPOLICY._serialized_end=2250
  _APIGEEINSTANCEXTIMEOUTS._serialized_start=2252
  _APIGEEINSTANCEXTIMEOUTS._serialized_end=2309
  _APIGEEINSTANCE._serialized_start=2312
  _APIGEEINSTANCE._serialized_end=2721
  _APIGEEINSTANCEATTACHMENTXTIMEOUTS._serialized_start=2723
  _APIGEEINSTANCEATTACHMENTXTIMEOUTS._serialized_end=2790
  _APIGEEINSTANCEATTACHMENT._serialized_start=2793
  _APIGEEINSTANCEATTACHMENT._serialized_end=3021
  _APIGEEORGANIZATIONXTIMEOUTS._serialized_start=3023
  _APIGEEORGANIZATIONXTIMEOUTS._serialized_end=3100
  _APIGEEORGANIZATION._serialized_start=3103
  _APIGEEORGANIZATION._serialized_end=3535
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class JobTemplateAccelerationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    mode: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mode: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode", "resource_info", b"resource_info"]) -> None: ...

global___JobTemplateAccelerationSettings = JobTemplateAccelerationSettings

@typing_extensions.final
class JobTemplateHopDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    WAIT_MINUTES_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    QUEUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    wait_minutes: builtins.int
    priority: builtins.int
    queue: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        wait_minutes: builtins.int = ...,
        priority: builtins.int = ...,
        queue: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["priority", b"priority", "queue", b"queue", "resource_info", b"resource_info", "wait_minutes", b"wait_minutes"]) -> None: ...

global___JobTemplateHopDestination = JobTemplateHopDestination

@typing_extensions.final
class JobTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SettingsJsonEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACCELERATION_SETTINGS_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    STATUS_UPDATE_INTERVAL_FIELD_NUMBER: builtins.int
    SETTINGS_JSON_FIELD_NUMBER: builtins.int
    QUEUE_FIELD_NUMBER: builtins.int
    HOP_DESTINATIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    category: builtins.str
    description: builtins.str
    @property
    def acceleration_settings(self) -> global___JobTemplateAccelerationSettings: ...
    priority: builtins.int
    status_update_interval: builtins.str
    @property
    def settings_json(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    queue: builtins.str
    @property
    def hop_destinations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobTemplateHopDestination]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        category: builtins.str = ...,
        description: builtins.str = ...,
        acceleration_settings: global___JobTemplateAccelerationSettings | None = ...,
        priority: builtins.int = ...,
        status_update_interval: builtins.str = ...,
        settings_json: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        queue: builtins.str = ...,
        hop_destinations: collections.abc.Iterable[global___JobTemplateHopDestination] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["acceleration_settings", b"acceleration_settings", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["acceleration_settings", b"acceleration_settings", "category", b"category", "description", b"description", "hop_destinations", b"hop_destinations", "name", b"name", "priority", b"priority", "queue", b"queue", "resource_info", b"resource_info", "settings_json", b"settings_json", "status_update_interval", b"status_update_interval", "tags", b"tags"]) -> None: ...

global___JobTemplate = JobTemplate

@typing_extensions.final
class MediaConvert(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_TEMPLATE_FIELD_NUMBER: builtins.int
    PRESET_FIELD_NUMBER: builtins.int
    QUEUE_FIELD_NUMBER: builtins.int
    @property
    def job_template(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobTemplate]: ...
    @property
    def preset(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Preset]: ...
    @property
    def queue(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Queue]: ...
    def __init__(
        self,
        *,
        job_template: collections.abc.Iterable[global___JobTemplate] | None = ...,
        preset: collections.abc.Iterable[global___Preset] | None = ...,
        queue: collections.abc.Iterable[global___Queue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_template", b"job_template", "preset", b"preset", "queue", b"queue"]) -> None: ...

global___MediaConvert = MediaConvert

@typing_extensions.final
class Preset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SettingsJsonEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SETTINGS_JSON_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    category: builtins.str
    description: builtins.str
    @property
    def settings_json(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        category: builtins.str = ...,
        description: builtins.str = ...,
        settings_json: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["category", b"category", "description", b"description", "name", b"name", "resource_info", b"resource_info", "settings_json", b"settings_json", "tags", b"tags"]) -> None: ...

global___Preset = Preset

@typing_extensions.final
class Queue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PRICING_PLAN_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    status: builtins.str
    description: builtins.str
    pricing_plan: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        status: builtins.str = ...,
        description: builtins.str = ...,
        pricing_plan: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "pricing_plan", b"pricing_plan", "resource_info", b"resource_info", "status", b"status", "tags", b"tags"]) -> None: ...

global___Queue = Queue



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_healthcare.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gcp/gcp_healthcare.proto\x12\x1aoak9.tython.gcp.healthcare\x1a\x13shared/shared.proto\"Q\n\x1fHealthcareConsentStoreXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x90\x03\n\x16HealthcareConsentStore\x12\x0f\n\x07\x64\x61taset\x18\x01 \x01(\t\x12\x1b\n\x13\x64\x65\x66\x61ult_consent_ttl\x18\x02 \x01(\t\x12\'\n\x1f\x65nable_consent_create_on_update\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12N\n\x06labels\x18\x05 \x03(\x0b\x32>.oak9.tython.gcp.healthcare.HealthcareConsentStore.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12M\n\x08timeouts\x18\x07 \x01(\x0b\x32;.oak9.tython.gcp.healthcare.HealthcareConsentStoreXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n*HealthcareConsentStoreIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9a\x02\n HealthcareConsentStoreIamBinding\x12\x18\n\x10\x63onsent_store_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x61taset\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0f\n\x07members\x18\x05 \x03(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12Y\n\tcondition\x18\x07 \x01(\x0b\x32\x46.oak9.tython.gcp.healthcare.HealthcareConsentStoreIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"c\n)HealthcareConsentStoreIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x97\x02\n\x1fHealthcareConsentStoreIamMember\x12\x18\n\x10\x63onsent_store_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x61taset\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0e\n\x06member\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12X\n\tcondition\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.healthcare.HealthcareConsentStoreIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb4\x01\n\x1fHealthcareConsentStoreIamPolicy\x12\x18\n\x10\x63onsent_store_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x61taset\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n\x1aHealthcareDatasetXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf9\x01\n\x11HealthcareDataset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x11\n\tself_link\x18\x05 \x01(\t\x12\x11\n\ttime_zone\x18\x06 \x01(\t\x12H\n\x08timeouts\x18\x07 \x01(\x0b\x32\x36.oak9.tython.gcp.healthcare.HealthcareDatasetXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n%HealthcareDatasetIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf9\x01\n\x1bHealthcareDatasetIamBinding\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12T\n\tcondition\x18\x06 \x01(\x0b\x32\x41.oak9.tython.gcp.healthcare.HealthcareDatasetIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n$HealthcareDatasetIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf6\x01\n\x1aHealthcareDatasetIamMember\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12S\n\tcondition\x18\x06 \x01(\x0b\x32@.oak9.tython.gcp.healthcare.HealthcareDatasetIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x98\x01\n\x1aHealthcareDatasetIamPolicy\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"?\n\'HealthcareDicomStoreXNotificationConfig\x12\x14\n\x0cpubsub_topic\x18\x01 \x01(\t\"O\n\x1dHealthcareDicomStoreXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb9\x03\n\x14HealthcareDicomStore\x12\x0f\n\x07\x64\x61taset\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12L\n\x06labels\x18\x03 \x03(\x0b\x32<.oak9.tython.gcp.healthcare.HealthcareDicomStore.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\tself_link\x18\x05 \x01(\t\x12`\n\x13notification_config\x18\x06 \x01(\x0b\x32\x43.oak9.tython.gcp.healthcare.HealthcareDicomStoreXNotificationConfig\x12K\n\x08timeouts\x18\x07 \x01(\x0b\x32\x39.oak9.tython.gcp.healthcare.HealthcareDicomStoreXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n(HealthcareDicomStoreIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x83\x02\n\x1eHealthcareDicomStoreIamBinding\x12\x16\n\x0e\x64icom_store_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12W\n\tcondition\x18\x06 \x01(\x0b\x32\x44.oak9.tython.gcp.healthcare.HealthcareDicomStoreIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"a\n\'HealthcareDicomStoreIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x80\x02\n\x1dHealthcareDicomStoreIamMember\x12\x16\n\x0e\x64icom_store_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12V\n\tcondition\x18\x06 \x01(\x0b\x32\x43.oak9.tython.gcp.healthcare.HealthcareDicomStoreIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9f\x01\n\x1dHealthcareDicomStoreIamPolicy\x12\x16\n\x0e\x64icom_store_id\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\">\n&HealthcareFhirStoreXNotificationConfig\x12\x14\n\x0cpubsub_topic\x18\x01 \x01(\t\"|\nBHealthcareFhirStoreXStreamConfigsXBigqueryDestinationXSchemaConfig\x12!\n\x19recursive_structure_depth\x18\x01 \x01(\x01\x12\x13\n\x0bschema_type\x18\x02 \x01(\t\"\xc3\x01\n5HealthcareFhirStoreXStreamConfigsXBigqueryDestination\x12\x13\n\x0b\x64\x61taset_uri\x18\x01 \x01(\t\x12u\n\rschema_config\x18\x02 \x01(\x0b\x32^.oak9.tython.gcp.healthcare.HealthcareFhirStoreXStreamConfigsXBigqueryDestinationXSchemaConfig\"\xac\x01\n!HealthcareFhirStoreXStreamConfigs\x12\x16\n\x0eresource_types\x18\x01 \x03(\t\x12o\n\x14\x62igquery_destination\x18\x02 \x01(\x0b\x32Q.oak9.tython.gcp.healthcare.HealthcareFhirStoreXStreamConfigsXBigqueryDestination\"N\n\x1cHealthcareFhirStoreXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa6\x05\n\x13HealthcareFhirStore\x12\x0f\n\x07\x64\x61taset\x18\x01 \x01(\t\x12%\n\x1d\x64isable_referential_integrity\x18\x02 \x01(\x08\x12#\n\x1b\x64isable_resource_versioning\x18\x03 \x01(\x08\x12\x1d\n\x15\x65nable_history_import\x18\x04 \x01(\x08\x12\x1c\n\x14\x65nable_update_create\x18\x05 \x01(\x08\x12\n\n\x02id\x18\x06 \x01(\t\x12K\n\x06labels\x18\x07 \x03(\x0b\x32;.oak9.tython.gcp.healthcare.HealthcareFhirStore.LabelsEntry\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12\x0f\n\x07version\x18\n \x01(\t\x12_\n\x13notification_config\x18\x0b \x01(\x0b\x32\x42.oak9.tython.gcp.healthcare.HealthcareFhirStoreXNotificationConfig\x12U\n\x0estream_configs\x18\x0c \x03(\x0b\x32=.oak9.tython.gcp.healthcare.HealthcareFhirStoreXStreamConfigs\x12J\n\x08timeouts\x18\r \x01(\x0b\x32\x38.oak9.tython.gcp.healthcare.HealthcareFhirStoreXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\'HealthcareFhirStoreIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x80\x02\n\x1dHealthcareFhirStoreIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x15\n\rfhir_store_id\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12V\n\tcondition\x18\x06 \x01(\x0b\x32\x43.oak9.tython.gcp.healthcare.HealthcareFhirStoreIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"`\n&HealthcareFhirStoreIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xfd\x01\n\x1cHealthcareFhirStoreIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x15\n\rfhir_store_id\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12U\n\tcondition\x18\x06 \x01(\x0b\x32\x42.oak9.tython.gcp.healthcare.HealthcareFhirStoreIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x01\n\x1cHealthcareFhirStoreIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x15\n\rfhir_store_id\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"?\n\'HealthcareHl7V2StoreXNotificationConfig\x12\x14\n\x0cpubsub_topic\x18\x01 \x01(\t\"P\n(HealthcareHl7V2StoreXNotificationConfigs\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x14\n\x0cpubsub_topic\x18\x02 \x01(\t\"{\n!HealthcareHl7V2StoreXParserConfig\x12\x19\n\x11\x61llow_null_header\x18\x01 \x01(\x08\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x1a\n\x12segment_terminator\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"O\n\x1dHealthcareHl7V2StoreXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf3\x04\n\x14HealthcareHl7V2Store\x12\x0f\n\x07\x64\x61taset\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12L\n\x06labels\x18\x03 \x03(\x0b\x32<.oak9.tython.gcp.healthcare.HealthcareHl7V2Store.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\tself_link\x18\x05 \x01(\t\x12`\n\x13notification_config\x18\x06 \x01(\x0b\x32\x43.oak9.tython.gcp.healthcare.HealthcareHl7V2StoreXNotificationConfig\x12\x62\n\x14notification_configs\x18\x07 \x03(\x0b\x32\x44.oak9.tython.gcp.healthcare.HealthcareHl7V2StoreXNotificationConfigs\x12T\n\rparser_config\x18\x08 \x01(\x0b\x32=.oak9.tython.gcp.healthcare.HealthcareHl7V2StoreXParserConfig\x12K\n\x08timeouts\x18\t \x01(\x0b\x32\x39.oak9.tython.gcp.healthcare.HealthcareHl7V2StoreXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n(HealthcareHl7V2StoreIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x84\x02\n\x1eHealthcareHl7V2StoreIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x17\n\x0fhl7_v2_store_id\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12W\n\tcondition\x18\x06 \x01(\x0b\x32\x44.oak9.tython.gcp.healthcare.HealthcareHl7V2StoreIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"a\n\'HealthcareHl7V2StoreIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x81\x02\n\x1dHealthcareHl7V2StoreIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x17\n\x0fhl7_v2_store_id\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12V\n\tcondition\x18\x06 \x01(\x0b\x32\x43.oak9.tython.gcp.healthcare.HealthcareHl7V2StoreIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa0\x01\n\x1dHealthcareHl7V2StoreIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x17\n\x0fhl7_v2_store_id\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_healthcare_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HEALTHCARECONSENTSTORE_LABELSENTRY._options = None
  _HEALTHCARECONSENTSTORE_LABELSENTRY._serialized_options = b'8\001'
  _HEALTHCAREDICOMSTORE_LABELSENTRY._options = None
  _HEALTHCAREDICOMSTORE_LABELSENTRY._serialized_options = b'8\001'
  _HEALTHCAREFHIRSTORE_LABELSENTRY._options = None
  _HEALTHCAREFHIRSTORE_LABELSENTRY._serialized_options = b'8\001'
  _HEALTHCAREHL7V2STORE_LABELSENTRY._options = None
  _HEALTHCAREHL7V2STORE_LABELSENTRY._serialized_options = b'8\001'
  _HEALTHCARECONSENTSTOREXTIMEOUTS._serialized_start=77
  _HEALTHCARECONSENTSTOREXTIMEOUTS._serialized_end=158
  _HEALTHCARECONSENTSTORE._serialized_start=161
  _HEALTHCARECONSENTSTORE._serialized_end=561
  _HEALTHCARECONSENTSTORE_LABELSENTRY._serialized_start=516
  _HEALTHCARECONSENTSTORE_LABELSENTRY._serialized_end=561
  _HEALTHCARECONSENTSTOREIAMBINDINGXCONDITION._serialized_start=563
  _HEALTHCARECONSENTSTOREIAMBINDINGXCONDITION._serialized_end=663
  _HEALTHCARECONSENTSTOREIAMBINDING._serialized_start=666
  _HEALTHCARECONSENTSTOREIAMBINDING._serialized_end=948
  _HEALTHCARECONSENTSTOREIAMMEMBERXCONDITION._serialized_start=950
  _HEALTHCARECONSENTSTOREIAMMEMBERXCONDITION._serialized_end=1049
  _HEALTHCARECONSENTSTOREIAMMEMBER._serialized_start=1052
  _HEALTHCARECONSENTSTOREIAMMEMBER._serialized_end=1331
  _HEALTHCARECONSENTSTOREIAMPOLICY._serialized_start=1334
  _HEALTHCARECONSENTSTOREIAMPOLICY._serialized_end=1514
  _HEALTHCAREDATASETXTIMEOUTS._serialized_start=1516
  _HEALTHCAREDATASETXTIMEOUTS._serialized_end=1592
  _HEALTHCAREDATASET._serialized_start=1595
  _HEALTHCAREDATASET._serialized_end=1844
  _HEALTHCAREDATASETIAMBINDINGXCONDITION._serialized_start=1846
  _HEALTHCAREDATASETIAMBINDINGXCONDITION._serialized_end=1941
  _HEALTHCAREDATASETIAMBINDING._serialized_start=1944
  _HEALTHCAREDATASETIAMBINDING._serialized_end=2193
  _HEALTHCAREDATASETIAMMEMBERXCONDITION._serialized_start=2195
  _HEALTHCAREDATASETIAMMEMBERXCONDITION._serialized_end=2289
  _HEALTHCAREDATASETIAMMEMBER._serialized_start=2292
  _HEALTHCAREDATASETIAMMEMBER._serialized_end=2538
  _HEALTHCAREDATASETIAMPOLICY._serialized_start=2541
  _HEALTHCAREDATASETIAMPOLICY._serialized_end=2693
  _HEALTHCAREDICOMSTOREXNOTIFICATIONCONFIG._serialized_start=2695
  _HEALTHCAREDICOMSTOREXNOTIFICATIONCONFIG._serialized_end=2758
  _HEALTHCAREDICOMSTOREXTIMEOUTS._serialized_start=2760
  _HEALTHCAREDICOMSTOREXTIMEOUTS._serialized_end=2839
  _HEALTHCAREDICOMSTORE._serialized_start=2842
  _HEALTHCAREDICOMSTORE._serialized_end=3283
  _HEALTHCAREDICOMSTORE_LABELSENTRY._serialized_start=516
  _HEALTHCAREDICOMSTORE_LABELSENTRY._serialized_end=561
  _HEALTHCAREDICOMSTOREIAMBINDINGXCONDITION._serialized_start=3285
  _HEALTHCAREDICOMSTOREIAMBINDINGXCONDITION._serialized_end=3383
  _HEALTHCAREDICOMSTOREIAMBINDING._serialized_start=3386
  _HEALTHCAREDICOMSTOREIAMBINDING._serialized_end=3645
  _HEALTHCAREDICOMSTOREIAMMEMBERXCONDITION._serialized_start=3647
  _HEALTHCAREDICOMSTOREIAMMEMBERXCONDITION._serialized_end=3744
  _HEALTHCAREDICOMSTOREIAMMEMBER._serialized_start=3747
  _HEALTHCAREDICOMSTOREIAMMEMBER._serialized_end=4003
  _HEALTHCAREDICOMSTOREIAMPOLICY._serialized_start=4006
  _HEALTHCAREDICOMSTOREIAMPOLICY._serialized_end=4165
  _HEALTHCAREFHIRSTOREXNOTIFICATIONCONFIG._serialized_start=4167
  _HEALTHCAREFHIRSTOREXNOTIFICATIONCONFIG._serialized_end=4229
  _HEALTHCAREFHIRSTOREXSTREAMCONFIGSXBIGQUERYDESTINATIONXSCHEMACONFIG._serialized_start=4231
  _HEALTHCAREFHIRSTOREXSTREAMCONFIGSXBIGQUERYDESTINATIONXSCHEMACONFIG._serialized_end=4355
  _HEALTHCAREFHIRSTOREXSTREAMCONFIGSXBIGQUERYDESTINATION._serialized_start=4358
  _HEALTHCAREFHIRSTOREXSTREAMCONFIGSXBIGQUERYDESTINATION._serialized_end=4553
  _HEALTHCAREFHIRSTOREXSTREAMCONFIGS._serialized_start=4556
  _HEALTHCAREFHIRSTOREXSTREAMCONFIGS._serialized_end=4728
  _HEALTHCAREFHIRSTOREXTIMEOUTS._serialized_start=4730
  _HEALTHCAREFHIRSTOREXTIMEOUTS._serialized_end=4808
  _HEALTHCAREFHIRSTORE._serialized_start=4811
  _HEALTHCAREFHIRSTORE._serialized_end=5489
  _HEALTHCAREFHIRSTORE_LABELSENTRY._serialized_start=516
  _HEALTHCAREFHIRSTORE_LABELSENTRY._serialized_end=561
  _HEALTHCAREFHIRSTOREIAMBINDINGXCONDITION._serialized_start=5491
  _HEALTHCAREFHIRSTOREIAMBINDINGXCONDITION._serialized_end=5588
  _HEALTHCAREFHIRSTOREIAMBINDING._serialized_start=5591
  _HEALTHCAREFHIRSTOREIAMBINDING._serialized_end=5847
  _HEALTHCAREFHIRSTOREIAMMEMBERXCONDITION._serialized_start=5849
  _HEALTHCAREFHIRSTOREIAMMEMBERXCONDITION._serialized_end=5945
  _HEALTHCAREFHIRSTOREIAMMEMBER._serialized_start=5948
  _HEALTHCAREFHIRSTOREIAMMEMBER._serialized_end=6201
  _HEALTHCAREFHIRSTOREIAMPOLICY._serialized_start=6204
  _HEALTHCAREFHIRSTOREIAMPOLICY._serialized_end=6361
  _HEALTHCAREHL7V2STOREXNOTIFICATIONCONFIG._serialized_start=6363
  _HEALTHCAREHL7V2STOREXNOTIFICATIONCONFIG._serialized_end=6426
  _HEALTHCAREHL7V2STOREXNOTIFICATIONCONFIGS._serialized_start=6428
  _HEALTHCAREHL7V2STOREXNOTIFICATIONCONFIGS._serialized_end=6508
  _HEALTHCAREHL7V2STOREXPARSERCONFIG._serialized_start=6510
  _HEALTHCAREHL7V2STOREXPARSERCONFIG._serialized_end=6633
  _HEALTHCAREHL7V2STOREXTIMEOUTS._serialized_start=6635
  _HEALTHCAREHL7V2STOREXTIMEOUTS._serialized_end=6714
  _HEALTHCAREHL7V2STORE._serialized_start=6717
  _HEALTHCAREHL7V2STORE._serialized_end=7344
  _HEALTHCAREHL7V2STORE_LABELSENTRY._serialized_start=516
  _HEALTHCAREHL7V2STORE_LABELSENTRY._serialized_end=561
  _HEALTHCAREHL7V2STOREIAMBINDINGXCONDITION._serialized_start=7346
  _HEALTHCAREHL7V2STOREIAMBINDINGXCONDITION._serialized_end=7444
  _HEALTHCAREHL7V2STOREIAMBINDING._serialized_start=7447
  _HEALTHCAREHL7V2STOREIAMBINDING._serialized_end=7707
  _HEALTHCAREHL7V2STOREIAMMEMBERXCONDITION._serialized_start=7709
  _HEALTHCAREHL7V2STOREIAMMEMBERXCONDITION._serialized_end=7806
  _HEALTHCAREHL7V2STOREIAMMEMBER._serialized_start=7809
  _HEALTHCAREHL7V2STOREIAMMEMBER._serialized_end=8066
  _HEALTHCAREHL7V2STOREIAMPOLICY._serialized_start=8069
  _HEALTHCAREHL7V2STOREIAMPOLICY._serialized_end=8229
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    kms_key_name: builtins.str
    def __init__(
        self,
        *,
        kms_key_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_name", b"kms_key_name"]) -> None: ...

global___SecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption = SecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption

@typing_extensions.final
class SecretManagerSecretXReplicationXUserManagedXReplicas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATION_FIELD_NUMBER: builtins.int
    CUSTOMER_MANAGED_ENCRYPTION_FIELD_NUMBER: builtins.int
    location: builtins.str
    @property
    def customer_managed_encryption(self) -> global___SecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption: ...
    def __init__(
        self,
        *,
        location: builtins.str = ...,
        customer_managed_encryption: global___SecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["customer_managed_encryption", b"customer_managed_encryption"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["customer_managed_encryption", b"customer_managed_encryption", "location", b"location"]) -> None: ...

global___SecretManagerSecretXReplicationXUserManagedXReplicas = SecretManagerSecretXReplicationXUserManagedXReplicas

@typing_extensions.final
class SecretManagerSecretXReplicationXUserManaged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLICAS_FIELD_NUMBER: builtins.int
    @property
    def replicas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecretManagerSecretXReplicationXUserManagedXReplicas]: ...
    def __init__(
        self,
        *,
        replicas: collections.abc.Iterable[global___SecretManagerSecretXReplicationXUserManagedXReplicas] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["replicas", b"replicas"]) -> None: ...

global___SecretManagerSecretXReplicationXUserManaged = SecretManagerSecretXReplicationXUserManaged

@typing_extensions.final
class SecretManagerSecretXReplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTOMATIC_FIELD_NUMBER: builtins.int
    USER_MANAGED_FIELD_NUMBER: builtins.int
    automatic: builtins.bool
    @property
    def user_managed(self) -> global___SecretManagerSecretXReplicationXUserManaged: ...
    def __init__(
        self,
        *,
        automatic: builtins.bool = ...,
        user_managed: global___SecretManagerSecretXReplicationXUserManaged | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_managed", b"user_managed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["automatic", b"automatic", "user_managed", b"user_managed"]) -> None: ...

global___SecretManagerSecretXReplication = SecretManagerSecretXReplication

@typing_extensions.final
class SecretManagerSecretXRotation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEXT_ROTATION_TIME_FIELD_NUMBER: builtins.int
    ROTATION_PERIOD_FIELD_NUMBER: builtins.int
    next_rotation_time: builtins.str
    rotation_period: builtins.str
    def __init__(
        self,
        *,
        next_rotation_time: builtins.str = ...,
        rotation_period: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_rotation_time", b"next_rotation_time", "rotation_period", b"rotation_period"]) -> None: ...

global___SecretManagerSecretXRotation = SecretManagerSecretXRotation

@typing_extensions.final
class SecretManagerSecretXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___SecretManagerSecretXTimeouts = SecretManagerSecretXTimeouts

@typing_extensions.final
class SecretManagerSecretXTopics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___SecretManagerSecretXTopics = SecretManagerSecretXTopics

@typing_extensions.final
class SecretManagerSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    REPLICATION_FIELD_NUMBER: builtins.int
    ROTATION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    expire_time: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    secret_id: builtins.str
    ttl: builtins.str
    @property
    def replication(self) -> global___SecretManagerSecretXReplication: ...
    @property
    def rotation(self) -> global___SecretManagerSecretXRotation: ...
    @property
    def timeouts(self) -> global___SecretManagerSecretXTimeouts: ...
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecretManagerSecretXTopics]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        expire_time: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        secret_id: builtins.str = ...,
        ttl: builtins.str = ...,
        replication: global___SecretManagerSecretXReplication | None = ...,
        rotation: global___SecretManagerSecretXRotation | None = ...,
        timeouts: global___SecretManagerSecretXTimeouts | None = ...,
        topics: collections.abc.Iterable[global___SecretManagerSecretXTopics] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["replication", b"replication", "resource_info", b"resource_info", "rotation", b"rotation", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "expire_time", b"expire_time", "id", b"id", "labels", b"labels", "name", b"name", "project", b"project", "replication", b"replication", "resource_info", b"resource_info", "rotation", b"rotation", "secret_id", b"secret_id", "timeouts", b"timeouts", "topics", b"topics", "ttl", b"ttl"]) -> None: ...

global___SecretManagerSecret = SecretManagerSecret

@typing_extensions.final
class SecretManagerSecretIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___SecretManagerSecretIamBindingXCondition = SecretManagerSecretIamBindingXCondition

@typing_extensions.final
class SecretManagerSecretIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    secret_id: builtins.str
    @property
    def condition(self) -> global___SecretManagerSecretIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        secret_id: builtins.str = ...,
        condition: global___SecretManagerSecretIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "secret_id", b"secret_id"]) -> None: ...

global___SecretManagerSecretIamBinding = SecretManagerSecretIamBinding

@typing_extensions.final
class SecretManagerSecretIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___SecretManagerSecretIamMemberXCondition = SecretManagerSecretIamMemberXCondition

@typing_extensions.final
class SecretManagerSecretIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    secret_id: builtins.str
    @property
    def condition(self) -> global___SecretManagerSecretIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        secret_id: builtins.str = ...,
        condition: global___SecretManagerSecretIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "secret_id", b"secret_id"]) -> None: ...

global___SecretManagerSecretIamMember = SecretManagerSecretIamMember

@typing_extensions.final
class SecretManagerSecretIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SECRET_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    secret_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        secret_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "secret_id", b"secret_id"]) -> None: ...

global___SecretManagerSecretIamPolicy = SecretManagerSecretIamPolicy

@typing_extensions.final
class SecretManagerSecretVersionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___SecretManagerSecretVersionXTimeouts = SecretManagerSecretVersionXTimeouts

@typing_extensions.final
class SecretManagerSecretVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESTROY_TIME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    SECRET_DATA_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    destroy_time: builtins.str
    enabled: builtins.bool
    id: builtins.str
    name: builtins.str
    secret: builtins.str
    secret_data: builtins.str
    @property
    def timeouts(self) -> global___SecretManagerSecretVersionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        destroy_time: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        secret: builtins.str = ...,
        secret_data: builtins.str = ...,
        timeouts: global___SecretManagerSecretVersionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "destroy_time", b"destroy_time", "enabled", b"enabled", "id", b"id", "name", b"name", "resource_info", b"resource_info", "secret", b"secret", "secret_data", b"secret_data", "timeouts", b"timeouts"]) -> None: ...

global___SecretManagerSecretVersion = SecretManagerSecretVersion
